==> pgn2data-0.0.3.tar.gz: pgn2data-0.0.3/converter/headers.py <==
file_headers_game = ["game_id",
                     "game_order",
                     "event",
                     "site",
                     "date_played",
                     "round",
                     "white",
                     "black",
                     "result",
                     "white_elo",
                     "white_rating_diff",
                     "black_elo",
                     "black_rating_diff",
                     "winner",
                     "winner_elo",
                     "loser",
                     "loser_elo",
                     "winner_loser_elo_diff",
                     "eco", "termination",
                     "time_control",
                     "utc_date",
                     "utc_time",
                     "variant",
                     "ply_count",
                     "date_created",
                     "file_name"]

file_headers_moves = ["game_id",
                      "move_no",
                      "player",
                      "notation",
                      "move",
                      "from_square",
                      "to_square",
                      "piece",
                      "color",
                      "fen",
                      "is_check",
                      "is_check_mate",
                      "is_fifty_moves",
                      "is_fivefold_repetition",
                      "is_game_over",
                      "is_insufficient_material",
                      "white_count",
                      "black_count",
                      "white_pawn_count",
                      "black_pawn_count",
                      "white_queen_count",
                      "black_queen_count",
                      "white_black_count",
                      "black_bishop_count",
                      "white_knight_count",
                      "black_knight_count",
                      "white_rook_count",
                      "black_rook_count",
                      "captured_score_for_white",
                      "captured_score_for_black",
                      "fen_row1_white_count",
                      "fen_row2_white_count",
                      "fen_row3_white_count",
                      "fen_row4_white_count",
                      "fen_row5_white_count",
                      "fen_row6_white_count",
                      "fen_row7_white_count",
                      "fen_row8_white_count",
                      "fen_row1_white_value",
                      "fen_row2_white_value",
                      "fen_row3_white_value",
                      "fen_row4_white_value",
                      "fen_row5_white_value",
                      "fen_row6_white_value",
                      "fen_row7_white_value",
                      "fen_row8_white_value",
                      "fen_row1_black_count",
                      "fen_row2_black_count",
                      "fen_row3_black_count",
                      "fen_row4_black_count",
                      "fen_row5_black_count",
                      "fen_row6_black_count",
                      "fen_row7_black_count",
                      "fen_row8_black_count",
                      "fen_row1_black_value",
                      "fen_row2_black_value",
                      "fen_row3_black_value",
                      "fen_row4_black_value",
                      "fen_row5_black_value",
                      "fen_row6_black_value",
                      "fen_row7_black_value",
                      "fen_row8_black_value",
                      "move_sequence"]

==> pgn2data-0.0.4.tar.gz: pgn2data-0.0.4/converter/headers.py <==
file_headers_game = ["game_id",
                     "game_order",
                     "event",
                     "site",
                     "date_played",
                     "round",
                     "white",
                     "black",
                     "result",
                     "white_elo",
                     "white_rating_diff",
                     "black_elo",
                     "black_rating_diff",
                     "white_title",
                     "black_title",
                     "winner",
                     "winner_elo",
                     "loser",
                     "loser_elo",
                     "winner_loser_elo_diff",
                     "eco", "termination",
                     "time_control",
                     "utc_date",
                     "utc_time",
                     "variant",
                     "ply_count",
                     "date_created",
                     "file_name"]

file_headers_moves = ["game_id",
                      "move_no",
                      "move_no_pair",
                      "player",
                      "notation",
                      "move",
                      "from_square",
                      "to_square",
                      "piece",
                      "color",
                      "fen",
                      "is_check",
                      "is_check_mate",
                      "is_fifty_moves",
                      "is_fivefold_repetition",
                      "is_game_over",
                      "is_insufficient_material",
                      "white_count",
                      "black_count",
                      "white_pawn_count",
                      "black_pawn_count",
                      "white_queen_count",
                      "black_queen_count",
                      "white_black_count",
                      "black_bishop_count",
                      "white_knight_count",
                      "black_knight_count",
                      "white_rook_count",
                      "black_rook_count",
                      "captured_score_for_white",
                      "captured_score_for_black",
                      "fen_row1_white_count",
                      "fen_row2_white_count",
                      "fen_row3_white_count",
                      "fen_row4_white_count",
                      "fen_row5_white_count",
                      "fen_row6_white_count",
                      "fen_row7_white_count",
                      "fen_row8_white_count",
                      "fen_row1_white_value",
                      "fen_row2_white_value",
                      "fen_row3_white_value",
                      "fen_row4_white_value",
                      "fen_row5_white_value",
                      "fen_row6_white_value",
                      "fen_row7_white_value",
                      "fen_row8_white_value",
                      "fen_row1_black_count",
                      "fen_row2_black_count",
                      "fen_row3_black_count",
                      "fen_row4_black_count",
                      "fen_row5_black_count",
                      "fen_row6_black_count",
                      "fen_row7_black_count",
                      "fen_row8_black_count",
                      "fen_row1_black_value",
                      "fen_row2_black_value",
                      "fen_row3_black_value",
                      "fen_row4_black_value",
                      "fen_row5_black_value",
                      "fen_row6_black_value",
                      "fen_row7_black_value",
                      "fen_row8_black_value",
                      "move_sequence"]

file_headers_stockfish = ["eval", "prev_eval", "diff_eval", "depth"]
